@@ -118,7 +118,7 @@ public:
     void setAddr(const struct sockaddr *pAddr);
 
     bool isFromLocalAddr(const sockaddr* server_addr) const;
-    
+
     void clearFlag( int flag )          {   m_iFlags &= ~flag;          }
     void setFlag( int flag )            {   m_iFlags |= flag;           }
     int isFlagSet( int flag ) const     {   return m_iFlags & flag;     }
@@ -176,7 +176,11 @@ public:
     short incSslNewConn()               {   return ++m_sslNewConn;      }
     short getSslNewConn()               {   return m_sslNewConn;        }
     void  setSslNewConn(int n)          {   m_sslNewConn = n;           }
-    void  setGeoInfo(GeoInfo *geoInfo)  {   m_pGeoInfo = geoInfo;       }
+    void  setGeoInfo(GeoInfo *geoInfo)  {
+        if (m_pGeoInfo)
+            delete m_pGeoInfo;
+        m_pGeoInfo = geoInfo;
+    }
     GeoInfo *getGeoInfo() const         {   return m_pGeoInfo;          }
 
 #ifdef USE_IP2LOCATION
