@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -1085,7 +1085,7 @@ int IpToGeo2::parseEnvLine(const char *pEnvAliasMap,
     }
     memcpy(database, pMap, slash - pMap);
     database[slash - pMap] = 0;
-    strncpy(map, slash, map_len);
+    lstrncpy(map, slash, map_len);
     return 0;
 }
 
@@ -1349,4 +1349,4 @@ GeoInfo *IpToGeo2::lookUpV6(const char *pIP)
     return lookUpV6(addr);
 }
 
-#endif //ENABLE_IPTOGEO2
\ No newline at end of file
+#endif //ENABLE_IPTOGEO2
