@@ -504,7 +504,8 @@ static struct lsquic_stream_if s_quic_if =
 };
 
 
-struct ssl_ctx_st * QuicEngine::getSslCtxCb(void *peer_ctx)
+struct ssl_ctx_st * QuicEngine::getSslCtxCb(void *peer_ctx,
+                                                const struct sockaddr *local)
 {
     UdpListener *pUdpListener = (UdpListener *) peer_ctx;
     return pUdpListener->getSslContext();
